==> guikachu-1.1.2.tar.gz: guikachu-1.1.2/src/form-editor/resizeable.h <==
//$Id: resizeable.h,v 1.5 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_RESIZEABLE_H
#define GUIKACHU_FORM_EDITOR_RESIZEABLE_H

#include <sigc++/basic_signal.h>
#include <sigc++/object.h>
#include "property.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Resizeable: public SigC::Object
	{
	    SigC::Signal0<void> &changed_propagate;
	    SigC::Signal0<void> manual_width_changed;
	    SigC::Signal0<void> manual_height_changed;

	protected:
	    Resizeable (SigC::Signal0<void> &changed);

	    virtual int get_auto_width ()  const = 0;
	    virtual int get_auto_height () const = 0;
	    
	public:
	    virtual ~Resizeable () {};
	    
	    virtual int get_display_width ()  const;
	    virtual int get_display_height () const;

	    Property<int>  width;
	    Property<bool> manual_width;
	    Property<int>  height;
	    Property<bool> manual_height;

	private:
	    void manual_width_cb  ();
	    void manual_height_cb ();
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_RESIZEABLE_H */

==> guikachu-1.1.4.tar.gz: guikachu-1.1.4/src/form-editor/resizeable.h <==
//$Id: resizeable.h,v 1.8 2002/01/30 17:33:10 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_RESIZEABLE_H
#define GUIKACHU_FORM_EDITOR_RESIZEABLE_H

#include <sigc++/basic_signal.h>
#include <sigc++/object.h>
#include "property.h"
#include "form-element.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Resizeable: public virtual FormElement,
			  public SigC::Object
	{
	    SigC::Signal0<void> &real_changed;
	    SigC::Signal0<void>  width_changed;
	    SigC::Signal0<void>  height_changed;
	    
	protected:
	    Resizeable (SigC::Signal0<void> &changed);
	    
	public:
	    virtual ~Resizeable () {};
	    
	    virtual int get_display_width  () const;
	    virtual int get_display_height () const;

	    Property<int>  width;
	    Property<int>  height;

	private:
	    void emit_changed ();
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_RESIZEABLE_H */
